Contributor Agreement
=====================

The submitter agrees by adding his or her name within the section below named
"Contributors" and submitting the resulting modified document to the
canonical shared repository location for this software project (whether
directly, as a user with "direct commit access", or via a "pull request"), he
or she is signing a contract electronically.  The submitter becomes a
Contributor after a) he or she signs this document by adding their name
beneath the "Contributors" section below, and b) the resulting document is
accepted into the canonical version control repository.

By submitting any code, documentation, modifications, or other contributions
(each a “Contribution”) to the project, you represent, warrant and agree that:
1. The Contributions are hereby licensed to the under the terms of the
   BSD 2-clause License (https://opensource.org/licenses/BSD-2-Clause).
2. You are the sole author and owner of each of your Contributions, you have
   the right to grant the license in Section 1, and projects exercise of such
   license will not infringe your or, to your knowledge, any other
   party’s intellectual property rights.
3. Project may freely assign and transfer this Contributor License Agreement
   to any third party.


List of Contributors
====================

The below-signed are contributors to a code repository that is part of the
project.  Each below-signed contributor has read,
understand and agrees to the terms above in the section within this document
entitled "Contributor Agreement" as of the date beside his or her name.

Current or previous core committers:

* Marcin Lulek (Ergo^) 2000-01-01

Contributors:

* Luke Crooks (crooksey)
* Svintsov Dmitry (uralbash) 2014-12-24
* Marcin Kuzminski (marcinkuzminski) 2011-11-14
* Lukasz Fidosz (virhilo) 2011-01-01
* Arian Maykon de Araújo Diógenes (arianmaykon) 2016-04-19
* Edward Arghiroiu (themightyonyx) 2015-11-13
* Łukasz Bołdys (utek) 2013-11-22
* Christian Benke (peletiah) 2017-02-19
* René Jochum (pcdummy) 2018-02-13
